@@ -2,8 +2,8 @@
  *  Header for MediaMVP server
  *
  *
- *  $Id: mediamvp.h,v 1.12 2003/11/18 23:04:59 dom Exp $
- *  $Date: 2003/11/18 23:04:59 $
+ *  $Id: mediamvp.h,v 1.16 2003/11/19 23:48:13 dom Exp $
+ *  $Date: 2003/11/19 23:48:13 $
  */
 
 #ifndef _MEDIAMVP_H_
@@ -64,6 +64,10 @@ typedef struct _mvprfbmsg mvprfbmsg_t;
 
 typedef struct {
     char      address[30];      /* Should be more than enough */
+    int       tvmode;
+    int       flickermode;
+    int       aspectratio;
+    int       videooutput;      /* Sent by client?!? */
     char      inuse;
     gui_t    *gui;
     stream_t *stream;
@@ -77,7 +81,7 @@ extern uint32_t        main_interfaceip;
 /* app.c */
 extern void            app_config();
 extern void            app_init();
-extern app_t          *new_app(render_t *render, gui_t *gui);
+extern app_t          *new_app(dongle_t *dongle, render_t *render, gui_t *gui);
 extern void            delete_app(app_t *app);
 
 
@@ -97,6 +101,7 @@ extern void            delete_gui(gui_t *gui);
 extern void            gui_register_keys(gui_t *gui,int type,int (*key_func)(void *app,int keycode), void *menu);
 extern void            gui_send_filename(gui_t *gui, char *name);
 extern void            gui_send_message(gui_t *gui, mvprfbmsg_t *msg);
+extern void            gui_send_settings(gui_t *gui, int subcommand);
 
 /* http.c */
 extern int             http_open(char *url);
@@ -124,22 +129,6 @@ extern int             udp_listen(const char *iface, int port);
 extern int             udp_send(char *data, int len, const char *addr, int port);
 
 /* render.c */
-
-/* All we need is updated as global access */
-struct _render {
-    int       width;
-    int       depth;
-    int       yuvsize;
-    uint8_t  *layers[3];
-    int       fgred;
-    int       fggreen;
-    int       fgblue;
-    int       bgred;
-    int       bggreen;
-    int       bgblue;
-    uint8_t   updated;
-};
-
 extern render_t       *new_render(int width, int depth);
 extern void            delete_render(render_t *render);
 extern void           *render_rgb2yvuy(render_t *render);
@@ -148,8 +137,10 @@ extern void            render_set_bgcol(render_t *render, int red, int green, in
 extern void            render_print(render_t *render, int x, int y, char *text);
 extern void            render_printrow(render_t *render, int row, char *text);
 extern void            render_clear(render_t *render);
-
-
+extern int             render_get_yuvsize(render_t *render);
+extern int             render_get_maxrows(render_t *render);
+extern int             render_get_depth(render_t *render);
+extern int             render_get_width(render_t *render);
 
 
 
